@@ -1,8 +1,5 @@
 package HTML::FormFu::Constraint::Equal;
-
-use strict;
-our $VERSION = '2.01_04'; # TRIAL VERSION
-
+$HTML::FormFu::Constraint::Equal::VERSION = '2.01';
 use Moose;
 extends 'HTML::FormFu::Constraint';
 
@@ -122,10 +119,6 @@ __END__
 
 HTML::FormFu::Constraint::Equal - Multi-field Equality Constraint
 
-=head1 VERSION
-
-version 2.01_04
-
 =head1 SYNOPSIS
 
     - type: Password
@@ -138,12 +131,12 @@ version 2.01_04
 
 =head1 DESCRIPTION
 
-All fields named in L<HTML::FormFu::Role::Constraint::Others/others> must have an equal value to the field this
+All fields named in L<HTML::FormFu::Role::Constraint::Others/others> must have an equal value to the field this 
 constraint is attached to.
 
 =head1 SEE ALSO
 
-Is a sub-class of, and inherits methods from
+Is a sub-class of, and inherits methods from  
 L<HTML::FormFu::Role::Constraint::Others>, L<HTML::FormFu::Constraint>
 
 L<HTML::FormFu>
