@@ -1,8 +1,5 @@
 package HTML::FormFu::Constraint::File::MinSize;
-
-use strict;
-our $VERSION = '2.01_04'; # TRIAL VERSION
-
+$HTML::FormFu::Constraint::File::MinSize::VERSION = '2.01';
 use Moose;
 extends 'HTML::FormFu::Constraint::File::Size';
 
@@ -22,15 +19,11 @@ __END__
 
 HTML::FormFu::Constraint::File::MinSize - Minimum File Size Constraint
 
-=head1 VERSION
-
-version 2.01_04
-
 =head1 DESCRIPTION
 
 Ensure that an uploaded file meets minimum size constraints.
 
-Overrides L<HTML::FormFu::Constraint/localize_args>, so that the value of
+Overrides L<HTML::FormFu::Constraint/localize_args>, so that the value of 
 L</minimum> is passed as an argument to L<localize|HTML::FormFu/localize>.
 
 This constraint doesn't honour the C<not()> value.
@@ -47,7 +40,7 @@ L</min> is an alias for L</minimum>.
 
 =head1 SEE ALSO
 
-Is a sub-class of, and inherits methods from L<HTML::FormFu::File::Size>,
+Is a sub-class of, and inherits methods from L<HTML::FormFu::File::Size>, 
 L<HTML::FormFu::Constraint>
 
 L<HTML::FormFu>
