@@ -1,8 +1,5 @@
 package HTML::FormFu::Constraint::Set;
-
-use strict;
-our $VERSION = '2.01_04'; # TRIAL VERSION
-
+$HTML::FormFu::Constraint::Set::VERSION = '2.01';
 use Moose;
 use MooseX::Attribute::FormFuChained;
 extends 'HTML::FormFu::Constraint';
@@ -45,10 +42,6 @@ __END__
 
 HTML::FormFu::Constraint::Set - Set of Values Constraint
 
-=head1 VERSION
-
-version 2.01_04
-
 =head1 SYNOPSIS
 
     type: Set
