@@ -1,8 +1,5 @@
 package HTML::FormFu::Deflator::PathClassFile;
-
-use strict;
-our $VERSION = '2.01_04'; # TRIAL VERSION
-
+$HTML::FormFu::Deflator::PathClassFile::VERSION = '2.01';
 use Moose;
 use MooseX::Attribute::FormFuChained;
 extends 'HTML::FormFu::Deflator';
@@ -45,10 +42,6 @@ __END__
 
 HTML::FormFu::Deflator::PathClassFile - Deflator for Path::Class::File objects
 
-=head1 VERSION
-
-version 2.01_04
-
 =head1 SYNOPSIS
 
     $form->deflator( PathClassFile => 'file' )
@@ -71,14 +64,14 @@ There are three types of deflation:
 
 =item relative
 
-Set this to 1 to deflate to a relative path. Anything else than 1 specifies the
-directory to use as the base of relativity - otherwise the current working
+Set this to 1 to deflate to a relative path. Anything else than 1 specifies the 
+directory to use as the base of relativity - otherwise the current working 
 directory will be used.
 
 =item absolute
 
-Set this to 1 to deflate to an absolute path. Anything else than 1 specifies the
-directory to use as the base of relativity - otherwise the current working
+Set this to 1 to deflate to an absolute path. Anything else than 1 specifies the 
+directory to use as the base of relativity - otherwise the current working 
 directory will be used.
 
 =item basename
