@@ -1,8 +1,5 @@
 package HTML::FormFu::Element::Checkboxgroup;
-
-use strict;
-our $VERSION = '2.01_04'; # TRIAL VERSION
-
+$HTML::FormFu::Element::Checkboxgroup::VERSION = '2.01';
 use Moose;
 use MooseX::Attribute::FormFuChained;
 extends 'HTML::FormFu::Element';
@@ -163,10 +160,6 @@ sub _string_field {
                 process_attrs( $option->{attributes} ),
                 ;
 
-            if ( defined $option->{label} ) {
-                $html .= sprintf "<p>%s</p>\n", $option->{label};
-            }
-
             for my $item ( @{ $option->{group} } ) {
                 $html .= sprintf
                     "<span%s>\n",
@@ -243,10 +236,6 @@ __END__
 
 HTML::FormFu::Element::Checkboxgroup - Group of checkbox form fields
 
-=head1 VERSION
-
-version 2.01_04
-
 =head1 SYNOPSIS
 
 YAML config:
@@ -264,8 +253,8 @@ YAML config:
 
 Convenient to use group of checkbox fields.
 
-Use the same syntax as you would to create a Select element optgroup to
-create Checkboxgroup sub-groups, see L<HTML::FormFu::Role::Element::Group/options>
+Use the same syntax as you would to create a Select element optgroup to 
+create Checkboxgroup sub-groups, see L<HTML::FormFu::Role::Element::Group/options> 
 for details.
 
 =head1 METHODS
@@ -284,8 +273,8 @@ See L<HTML::FormFu::Role::Element::Group/value_range>.
 
 =head2 auto_id
 
-In addition to the substitutions documented by L<HTML::FormFu/auto_id>,
-C<%c> will be replaced by an incremented integer, to ensure there are
+In addition to the substitutions documented by L<HTML::FormFu/auto_id>, 
+C<%c> will be replaced by an incremented integer, to ensure there are 
 no duplicated ID's, and C<%v> will be replaced by the item's value to
 allow multiple elements with the same name to coexist, and their labels
 to correctly select the appropriate item.
@@ -310,9 +299,9 @@ Default Value: C<true>
 
 =head1 SEE ALSO
 
-Is a sub-class of, and inherits methods from
-L<HTML::FormFu::Role::Element::Group>,
-L<HTML::FormFu::Role::Element::Field>,
+Is a sub-class of, and inherits methods from 
+L<HTML::FormFu::Role::Element::Group>, 
+L<HTML::FormFu::Role::Element::Field>, 
 L<HTML::FormFu::Element>
 
 L<HTML::FormFu>
