@@ -1,8 +1,5 @@
 package HTML::FormFu::Element::DateTime;
-
-use strict;
-our $VERSION = '2.01_04'; # TRIAL VERSION
-
+$HTML::FormFu::Element::DateTime::VERSION = '2.01';
 use Moose;
 use MooseX::Attribute::FormFuChained;
 extends 'HTML::FormFu::Element::Date';
@@ -182,10 +179,6 @@ __END__
 
 HTML::FormFu::Element::DateTime - Date / Time combo field
 
-=head1 VERSION
-
-version 2.01_04
-
 =head1 SYNOPSIS
 
     ---
@@ -223,10 +216,10 @@ Arguments: $value
 
 Arguments: \@values
 
-A string or arrayref of strings to be inserted into the start of the select
+A string or arrayref of strings to be inserted into the start of the select 
 menu.
 
-Each value is only used as the label for a select item - the value for each
+Each value is only used as the label for a select item - the value for each 
 of these items is always the empty string C<''>.
 
 =head3 prefix_loc
@@ -263,10 +256,10 @@ Arguments: $value
 
 Arguments: \@values
 
-A string or arrayref of strings to be inserted into the start of the select
+A string or arrayref of strings to be inserted into the start of the select 
 menu.
 
-Each value is only used as the label for a select item - the value for each
+Each value is only used as the label for a select item - the value for each 
 of these items is always the empty string C<''>.
 
 =head3 prefix_loc
@@ -303,10 +296,10 @@ Arguments: $value
 
 Arguments: \@values
 
-A string or arrayref of strings to be inserted into the start of the select
+A string or arrayref of strings to be inserted into the start of the select 
 menu.
 
-Each value is only used as the label for a select item - the value for each
+Each value is only used as the label for a select item - the value for each 
 of these items is always the empty string C<''>.
 
 =head3 prefix_loc
@@ -351,9 +344,9 @@ See L<HTML::FormFu::Element::Date/CAVEATS>
 
 Is a sub-class of, and inherits methods from
 L<HTML::FormFu::Element::Date>
-L<HTML::FormFu::Role::Element::Field>,
-L<HTML::FormFu::Element::Multi>,
-L<HTML::FormFu::Element::Block>,
+L<HTML::FormFu::Role::Element::Field>, 
+L<HTML::FormFu::Element::Multi>, 
+L<HTML::FormFu::Element::Block>, 
 L<HTML::FormFu::Element>
 
 L<HTML::FormFu>
