@@ -1,8 +1,5 @@
 package HTML::FormFu::Element::Hidden;
-
-use strict;
-our $VERSION = '2.01_04'; # TRIAL VERSION
-
+$HTML::FormFu::Element::Hidden::VERSION = '2.01';
 use Moose;
 
 extends 'HTML::FormFu::Element';
@@ -32,10 +29,6 @@ __END__
 
 HTML::FormFu::Element::Hidden - Hidden form field
 
-=head1 VERSION
-
-version 2.01_04
-
 =head1 SYNOPSIS
 
     my $e = $form->element( Hidden => 'foo' );
@@ -48,9 +41,9 @@ Hidden form field.
 
 =head1 SEE ALSO
 
-Is a sub-class of, and inherits methods from
-L<HTML::FormFu::Role::Element::Input>,
-L<HTML::FormFu::Role::Element::Field>,
+Is a sub-class of, and inherits methods from 
+L<HTML::FormFu::Role::Element::Input>, 
+L<HTML::FormFu::Role::Element::Field>, 
 L<HTML::FormFu::Element>
 
 L<HTML::FormFu>
