@@ -1,8 +1,5 @@
 package HTML::FormFu::Element::Number;
-
-use strict;
-our $VERSION = '2.01_04'; # TRIAL VERSION
-
+$HTML::FormFu::Element::Number::VERSION = '2.01';
 use Moose;
 
 extends 'HTML::FormFu::Element::Text';
@@ -39,10 +36,6 @@ __END__
 
 HTML::FormFu::Element::Number - Number element with formatting
 
-=head1 VERSION
-
-version 2.01_04
-
 =head1 SYNOPSIS
 
   ---
@@ -72,7 +65,7 @@ Set the precision for the number. Defaults to C<2>.
 
 =head2 trailing_zeroes
 
-If this is set to C<1> the number has trailing zeroes. Defaults to C<0>.
+If this is set to C<1> the number has trailing zeroes. Defaults to C<0>. 
 
 =head2 CHANGED BEHAVIOUR AS OF VERSION 0.09011
 
