@@ -1,8 +1,5 @@
 package HTML::FormFu::Exception;
-
-use strict;
-our $VERSION = '2.01_04'; # TRIAL VERSION
-
+$HTML::FormFu::Exception::VERSION = '2.01';
 use Moose;
 
 with 'HTML::FormFu::Role::Populate';
