@@ -1,8 +1,5 @@
 package HTML::FormFu::Exception::Transformer;
-
-use strict;
-our $VERSION = '2.01_04'; # TRIAL VERSION
-
+$HTML::FormFu::Exception::Transformer::VERSION = '2.01';
 use Moose;
 extends 'HTML::FormFu::Exception::Input';
 
