@@ -1,8 +1,5 @@
 package HTML::FormFu::Filter::FormatNumber;
-
-use strict;
-our $VERSION = '2.01_04'; # TRIAL VERSION
-
+$HTML::FormFu::Filter::FormatNumber::VERSION = '2.01';
 use Moose;
 extends 'HTML::FormFu::Filter';
 
@@ -45,10 +42,6 @@ __END__
 
 HTML::FormFu::Filter::FormatNumber - Convert a formatted number from a known locale
 
-=head1 VERSION
-
-version 2.01_04
-
 =head1 SYNOPSIS
 
 This filter simply does the opposite of
@@ -72,7 +65,7 @@ See L<Number::Format/unformat_number> for more details.
 
 If no locale is found, the server's locale will be used.
 
-This method is a special 'inherited accessor', which means it can be set on
+This method is a special 'inherited accessor', which means it can be set on 
 the form, a enclosing block element, the field, or this filter.
 When the value is read, if no value is defined it automatically traverses
 the element's hierarchy of parents, through any block elements and up to the
