@@ -1,8 +1,5 @@
 package HTML::FormFu::Filter::HTMLEscape;
-
-use strict;
-our $VERSION = '2.01_04'; # TRIAL VERSION
-
+$HTML::FormFu::Filter::HTMLEscape::VERSION = '2.01';
 use Moose;
 extends 'HTML::FormFu::Filter';
 
@@ -29,10 +26,6 @@ __END__
 
 HTML::FormFu::Filter::HTMLEscape - filter escaping HTML
 
-=head1 VERSION
-
-version 2.01_04
-
 =head1 DESCRIPTION
 
 HTML escaping filter.
@@ -41,7 +34,7 @@ HTML escaping filter.
 
 Carl Franks, C<cfranks@cpan.org>
 
-Based on the original source code of L<HTML::Widget::Filter::HTMLEscape>, by
+Based on the original source code of L<HTML::Widget::Filter::HTMLEscape>, by 
 Lyo Kato, C<lyo.kato@gmail.com>
 
 =head1 LICENSE
