@@ -1,8 +1,5 @@
 package HTML::FormFu::Filter::HTMLScrubber;
-
-use strict;
-our $VERSION = '2.01_04'; # TRIAL VERSION
-
+$HTML::FormFu::Filter::HTMLScrubber::VERSION = '2.01';
 use Moose;
 use MooseX::Attribute::FormFuChained;
 extends 'HTML::FormFu::Filter';
@@ -54,10 +51,6 @@ __END__
 
 HTML::FormFu::Filter::HTMLScrubber - filter removing HTML markup
 
-=head1 VERSION
-
-version 2.01_04
-
 =head1 DESCRIPTION
 
 Remove HTML markup using L<HTML::Scrubber>.
@@ -77,7 +70,7 @@ Carl Franks, C<cfranks@cpan.org>
 
 Extended by Nigel Metheringham, C<nigelm@cpan.org>
 
-Based on the original source code of L<HTML::Widget::Filter::HTMLStrip>, by
+Based on the original source code of L<HTML::Widget::Filter::HTMLStrip>, by 
 Lyo Kato, C<lyo.kato@gmail.com>
 
 =head1 LICENSE
