@@ -1,8 +1,5 @@
 package HTML::FormFu::Filter::NonNumeric;
-
-use strict;
-our $VERSION = '2.01_04'; # TRIAL VERSION
-
+$HTML::FormFu::Filter::NonNumeric::VERSION = '2.01';
 use Moose;
 extends 'HTML::FormFu::Filter::Regex';
 
@@ -18,10 +15,6 @@ __END__
 
 HTML::FormFu::Filter::NonNumeric - filter removing all non-numeric characters
 
-=head1 VERSION
-
-version 2.01_04
-
 =head1 DESCRIPTION
 
 Remove all non-numeric characters.
