@@ -1,8 +1,5 @@
 package HTML::FormFu::Filter::Whitespace;
-
-use strict;
-our $VERSION = '2.01_04'; # TRIAL VERSION
-
+$HTML::FormFu::Filter::Whitespace::VERSION = '2.01';
 use Moose;
 extends 'HTML::FormFu::Filter::Regex';
 
@@ -18,10 +15,6 @@ __END__
 
 HTML::FormFu::Filter::Whitespace - filter stripping all whitespace
 
-=head1 VERSION
-
-version 2.01_04
-
 =head1 DESCRIPTION
 
 Removes all whitespace.
@@ -30,7 +23,7 @@ Removes all whitespace.
 
 Carl Franks, C<cfranks@cpan.org>
 
-Based on the original source code of L<HTML::Widget::Filter::Whitespace>, by
+Based on the original source code of L<HTML::Widget::Filter::Whitespace>, by 
 Sebastian Riedel, C<sri@oook.de>
 
 =head1 LICENSE
