@@ -1,10 +1,7 @@
 package HTML::FormFu::I18N::da;
-
+$HTML::FormFu::I18N::da::VERSION = '2.01';
 use utf8;
 
-use strict;
-our $VERSION = '2.01_04'; # TRIAL VERSION
-
 use Moose;
 extends 'HTML::FormFu::I18N';
 
