@@ -1,8 +1,5 @@
 package HTML::FormFu::OutputProcessor::StripWhitespace;
-
-use strict;
-our $VERSION = '2.01_04'; # TRIAL VERSION
-
+$HTML::FormFu::OutputProcessor::StripWhitespace::VERSION = '2.01';
 use Moose;
 use MooseX::Attribute::FormFuChained;
 extends 'HTML::FormFu::OutputProcessor';
@@ -123,10 +120,7 @@ sub process {
 __PACKAGE__->meta->make_immutable;
 
 package HTML::FormFu::OutputProcessor::StripWhitespace::_iter;
-
-use strict;
-our $VERSION = '2.01_04'; # TRIAL VERSION
-
+$HTML::FormFu::OutputProcessor::StripWhitespace::_iter::VERSION = '2.01';
 use Moose;
 use MooseX::Attribute::FormFuChained;
 
@@ -174,10 +168,6 @@ __END__
 
 HTML::FormFu::OutputProcessor::StripWhitespace - Strip shitespace from HTML output
 
-=head1 VERSION
-
-version 2.01_04
-
 =head1 SYNOPSIS
 
     ---
