@@ -1,8 +1,5 @@
 package HTML::FormFu::Role::Constraint::Others;
-
-use strict;
-our $VERSION = '2.01_04'; # TRIAL VERSION
-
+$HTML::FormFu::Role::Constraint::Others::VERSION = '2.01';
 use Moose::Role;
 use MooseX::Attribute::FormFuChained;
 
@@ -215,10 +212,6 @@ __END__
 
 HTML::FormFu::Role::Constraint::Others - Base class for constraints needing others() method
 
-=head1 VERSION
-
-version 2.01_04
-
 =head1 METHODS
 
 =head2 others
@@ -239,7 +232,7 @@ to this block are considered siblings.
 
 =head2 attach_errors_to_base
 
-If true, any error will cause the error message to be associated with the
+If true, any error will cause the error message to be associated with the 
 field the constraint is attached to.
 
 Can be use in conjunction with L</attach_errors_to_others>.
@@ -248,7 +241,7 @@ Is ignored if L</attach_errors_to> is set.
 
 =head2 attach_errors_to_others
 
-If true, any error will cause the error message to be associated with every
+If true, any error will cause the error message to be associated with every 
 field named in L</others>.
 
 Can be use in conjunction with L</attach_errors_to_base>.
@@ -259,7 +252,7 @@ Is ignored if L</attach_errors_to> is set.
 
 Arguments: \@field_names
 
-Any error will cause the error message to be associated with every field
+Any error will cause the error message to be associated with every field 
 named in L</attach_errors_to>.
 
 Overrides L</attach_errors_to_base> and L</attach_errors_to_others>.
