@@ -1,8 +1,5 @@
 package HTML::FormFu::Role::ContainsElementsSharedWithField;
-
-use strict;
-our $VERSION = '2.01_04'; # TRIAL VERSION
-
+$HTML::FormFu::Role::ContainsElementsSharedWithField::VERSION = '2.01';
 use Moose::Role;
 
 use HTML::FormFu::Util qw(
