@@ -1,8 +1,5 @@
 package HTML::FormFu::Role::CreateChildren;
-
-use strict;
-our $VERSION = '2.01_04'; # TRIAL VERSION
-
+$HTML::FormFu::Role::CreateChildren::VERSION = '2.01';
 use Moose::Role;
 
 use HTML::FormFu::Util qw( _merge_hashes require_class );
