@@ -1,15 +1,15 @@
 package HTML::FormFu::Upload;
-
-use strict;
-our $VERSION = '2.01_04'; # TRIAL VERSION
-
+$HTML::FormFu::Upload::VERSION = '2.01';
 use Moose;
 use MooseX::Attribute::FormFuChained;
 
 with 'HTML::FormFu::Role::Populate';
 
+use Carp qw( croak );
+
 use HTML::FormFu::ObjectUtil qw( form parent );
 use HTML::FormFu::UploadParam;
+use Scalar::Util qw( reftype );
 
 has headers  => ( is => 'rw', traits => ['FormFuChained'] );
 has filename => ( is => 'rw', traits => ['FormFuChained'] );
@@ -56,10 +56,6 @@ __END__
 
 HTML::FormFu::Upload - uploaded file
 
-=head1 VERSION
-
-version 2.01_04
-
 =head1 DESCRIPTION
 
 An instance is created for each uploaded file.
@@ -86,7 +82,7 @@ object is associated with.
 
 =head2 form
 
-Returns the L<HTML::FormFu> object that the upload object's field is attached
+Returns the L<HTML::FormFu> object that the upload object's field is attached 
 to.
 
 =head2 populate
