@@ -1,8 +1,5 @@
 package HTML::FormFu::Validator;
-
-use strict;
-our $VERSION = '2.01_04'; # TRIAL VERSION
-
+$HTML::FormFu::Validator::VERSION = '2.01';
 use Moose;
 extends 'HTML::FormFu::Processor';
 
@@ -78,10 +75,6 @@ __END__
 
 HTML::FormFu::Validator - Validator Base Class
 
-=head1 VERSION
-
-version 2.01_04
-
 =head1 SYNOPSIS
 
 =head1 DESCRIPTION
@@ -109,10 +102,7 @@ Then, the form config file would just need:
 And the class would be something like this:
 
     package HTML::FormFu::Validator::MyApp::SomeValidator;
-    use strict;
-# VERSION
-
-use Moose;
+    use Moose;
     extends 'HTML::FormFu::Validator';
 
     sub validate_value {
